#line 1 "nksp.cpp"

#line 3 "nksp.cpp"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define Nksp__create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer Nksp__create_buffer
#endif

#ifdef yy_delete_buffer
#define Nksp__delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer Nksp__delete_buffer
#endif

#ifdef yy_scan_buffer
#define Nksp__scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer Nksp__scan_buffer
#endif

#ifdef yy_scan_string
#define Nksp__scan_string_ALREADY_DEFINED
#else
#define yy_scan_string Nksp__scan_string
#endif

#ifdef yy_scan_bytes
#define Nksp__scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes Nksp__scan_bytes
#endif

#ifdef yy_init_buffer
#define Nksp__init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer Nksp__init_buffer
#endif

#ifdef yy_flush_buffer
#define Nksp__flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer Nksp__flush_buffer
#endif

#ifdef yy_load_buffer_state
#define Nksp__load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state Nksp__load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define Nksp__switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer Nksp__switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define Nksp_push_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state Nksp_push_buffer_state
#endif

#ifdef yypop_buffer_state
#define Nksp_pop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state Nksp_pop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define Nksp_ensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack Nksp_ensure_buffer_stack
#endif

#ifdef yylex
#define Nksp_lex_ALREADY_DEFINED
#else
#define yylex Nksp_lex
#endif

#ifdef yyrestart
#define Nksp_restart_ALREADY_DEFINED
#else
#define yyrestart Nksp_restart
#endif

#ifdef yylex_init
#define Nksp_lex_init_ALREADY_DEFINED
#else
#define yylex_init Nksp_lex_init
#endif

#ifdef yylex_init_extra
#define Nksp_lex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra Nksp_lex_init_extra
#endif

#ifdef yylex_destroy
#define Nksp_lex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy Nksp_lex_destroy
#endif

#ifdef yyget_debug
#define Nksp_get_debug_ALREADY_DEFINED
#else
#define yyget_debug Nksp_get_debug
#endif

#ifdef yyset_debug
#define Nksp_set_debug_ALREADY_DEFINED
#else
#define yyset_debug Nksp_set_debug
#endif

#ifdef yyget_extra
#define Nksp_get_extra_ALREADY_DEFINED
#else
#define yyget_extra Nksp_get_extra
#endif

#ifdef yyset_extra
#define Nksp_set_extra_ALREADY_DEFINED
#else
#define yyset_extra Nksp_set_extra
#endif

#ifdef yyget_in
#define Nksp_get_in_ALREADY_DEFINED
#else
#define yyget_in Nksp_get_in
#endif

#ifdef yyset_in
#define Nksp_set_in_ALREADY_DEFINED
#else
#define yyset_in Nksp_set_in
#endif

#ifdef yyget_out
#define Nksp_get_out_ALREADY_DEFINED
#else
#define yyget_out Nksp_get_out
#endif

#ifdef yyset_out
#define Nksp_set_out_ALREADY_DEFINED
#else
#define yyset_out Nksp_set_out
#endif

#ifdef yyget_leng
#define Nksp_get_leng_ALREADY_DEFINED
#else
#define yyget_leng Nksp_get_leng
#endif

#ifdef yyget_text
#define Nksp_get_text_ALREADY_DEFINED
#else
#define yyget_text Nksp_get_text
#endif

#ifdef yyget_lineno
#define Nksp_get_lineno_ALREADY_DEFINED
#else
#define yyget_lineno Nksp_get_lineno
#endif

#ifdef yyset_lineno
#define Nksp_set_lineno_ALREADY_DEFINED
#else
#define yyset_lineno Nksp_set_lineno
#endif

#ifdef yyget_column
#define Nksp_get_column_ALREADY_DEFINED
#else
#define yyget_column Nksp_get_column
#endif

#ifdef yyset_column
#define Nksp_set_column_ALREADY_DEFINED
#else
#define yyset_column Nksp_set_column
#endif

#ifdef yywrap
#define Nksp_wrap_ALREADY_DEFINED
#else
#define yywrap Nksp_wrap
#endif

#ifdef yyalloc
#define Nksp_alloc_ALREADY_DEFINED
#else
#define yyalloc Nksp_alloc
#endif

#ifdef yyrealloc
#define Nksp_realloc_ALREADY_DEFINED
#else
#define yyrealloc Nksp_realloc
#endif

#ifdef yyfree
#define Nksp_free_ALREADY_DEFINED
#else
#define yyfree Nksp_free
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define Nksp_wrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 41
#define YY_END_OF_BUFFER 42
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_acclist[893] =
    {   0,
       21,   22,   21,   22,   27,   27,   42,   40,   41,   38,
       40,   41,   36,   41,   39,   40,   41,   40,   41,   40,
       41,   40,   41,   40,   41,    2,   40,   41,16387,16388,
       40,   41,   40,   41,   35,   40,   41,   35,   40,   41,
       35,   40,   41,   35,   40,   41,   35,   40,   41,   35,
       40,   41,   35,   40,   41,   35,   40,   41,   35,   40,
       41,   35,   40,   41,   35,   40,   41,   35,   40,   41,
       35,   40,   41,   35,   40,   41,   35,   40,   41,   35,
       40,   41,   35,   40,   41,   35,   40,   41,   35,   40,
       41,   40,   41,   40,   41,   35,   40,   41,   35,   40,

       41,   35,   40,   41,   35,   40,   41,   35,   40,   41,
       38,   40,   41,   40,   41,   10,   40,   41,    9,   40,
       41,    9,   40,   41,    9,   40,   41,    9,   40,   41,
        9,   40,   41,   38,   40,   41,   40,   41,   13,   40,
       41,   12,   40,   41,   12,   40,   41,   12,   40,   41,
       12,   40,   41,   12,   40,   41,   16,   40,   41,   16,
       40,   41,   16,   40,   41,   16,   40,   41,   16,   40,
       41,   17,   40,   41,   17,   40,   41,   17,   40,   41,
       17,   40,   41,   17,   40,   41,   22,   40,   41,   21,
       22,   38,   40,   41,   21,   36,   41,   21,   22,   40,

       41,   22,   40,   41,   22,   40,   41,   22,   40,   41,
       22,   40,   41,   38,   40,   41,   40,   41,   18,   40,
       41,   40,   41,   40,   41,   40,   41,   40,   41,   38,
       40,   41,   40,   41,   19,   40,   41,   38,   40,   41,
       40,   41,   25,   40,   41,   25,   40,   41,   25,   40,
       41,   25,   40,   41,   25,   40,   41,   27,   38,   40,
       41,   27,   40,   41,   40,   41,   40,   41,   40,   41,
       40,   41,   40,   41,    5,   40,   41,16390,    5,   40,
       41,16390,    7,   40,   41,   40,   41,   39,    1,   30,
       30,   33,   33,    2,16387,16388, 8196, 8195, 8195,   34,

       34,   32,   32,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   29,   35,   35,   35,
       35,   24,   35,   35,   35,   35,   35,   35,   37,   31,
       31,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   10,    9,    9,    9,    9,    9,    9,   13,
       12,   12,   12,   12,   12,   12,   16,   16,   16,   16,
       16,   16,   17,   17,   17,   17,   17,   17,   22,   22,
       21,   22,   21,   22,   22,   22,   22,   18,   19,   25,
       25,   25,   25,   25,   25,   25,   25,   27,   27, 8198,
        5,16390,    5,16390,    5,16390,    7,    1,   30,   30,

       30,   33,   33,   33,    2,16387,16388, 8195, 8195,   34,
       34,   34,   32,   32,   32,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   26,   35,   35,   35,   35,   35,
       35,   35,   35,   37,   31,   31,   31,   35,   35,   29,
       35,   35,   35,   23,   35,   35,   35,    9,    9,    9,
        9,   12,   12,   12,   12,   16,   16,   16,   16,   17,
       17,   17,   17,   22,   22,   22,   22,   25,   25,   25,
       25,   30,   33,   28,   34,   32,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   31,
       35,   35,   35,   35,    9,    9,    9,    9,   12,   12,

       12,   12,   16,   16,   16,   16,   17,   17,   17,   17,
       22,   22,   22,   22,   25,   25,   25,   25,   30,   33,
       34,   32,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   31,   35,   35,    9,    9,    9,    9,   12,   12,
       12,   12,   16,   16,   16,   16,   17,   17,   17,   17,
       22,   22,   22,   22,   25,   25,   25,   25,   30,   33,
       34,   32,   35,   35,   35,   35,   35,   35,   35,   35,
       31,   35,   35,    9,    9,    9,    9,   12,   12,   12,
       12,   16,   16,   16,   16,   17,   17,   17,   17,   22,
       22,   22,   22,   25,   25,   25,   25,   30,   33,   34,

       32,   35,   35,   35,   35,   35,   35,   35,   31,   35,
        9,    9,    9,    9,   12,   12,   12,   12,   16,   16,
       16,   16,   17,   17,   17,   17,   22,   22,   22,   22,
       25,   25,   25,   25,   30,   33,   34,   32,   35,   35,
       35,   35,   35,   35,   31,   35,    9,    9,    9,    9,
       12,   12,   12,   12,   16,   16,   16,   16,   17,   17,
       17,   17,   22,   22,   22,   22,   25,   25,   25,   25,
       30,   33,   34,   32,   35,   35,   35,   35,   35,   35,
       31,   35,    9,    9,    9,    9,   12,   12,   12,   12,
       16,   16,   16,   16,   17,   17,   17,   17,   22,   22,

       22,   22,   25,   25,   25,   25,   30,   33,   34,   32,
       35,   35,   35,   35,   35,   31,    9,    9,    9,    9,
       12,   12,   12,   12,   16,   16,   16,   16,   17,   17,
       17,   17,   22,   22,   22,   22,   25,   25,   25,   25,
       30,   33,   34,   32,   35,   35,   35,   35,   35,   31,
        9,    9,    9,    9,   12,   12,   12,   12,   16,   16,
       16,   16,   17,   17,   17,   17,   22,   22,   22,   22,
       25,   25,   25,   25,   30,   33,   34,   32,   20,   35,
       35,   35,   14,   35,   31,    9,   20,    9,    9,    9,
       12,   20,   12,   12,   12,   16,   20,   16,   16,   16,

       17,   20,   17,   17,   17,   20,   22,   22,   22,   22,
       14,   22,   22,   20,   20,   25,   25,   25,   25,   20,
       20,   30,   20,   33,   20,   34,   20,   32,   35,   35,
       35,   20,   20,   31,    9,    9,    9,   12,   12,   12,
       16,   16,   16,   17,   17,   17,   22,   22,   22,   25,
       25,   25,   35,    8,   35,    9,    9,   12,   12,   16,
       16,   17,   17,   22,   22,    8,   22,   22,   25,   25,
       35,   35,    9,    9,   12,   12,   16,   16,   17,   17,
       22,   22,   25,   25,   11,   15,   22,   11,   22,   22,
       15,   22

    } ;

static const flex_int16_t yy_accept[831] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    3,    5,    5,    5,    5,    5,    5,
        5,    6,    7,    7,    7,    7,    7,    8,   10,   13,
       15,   18,   20,   22,   24,   26,   31,   33,   35,   38,
       41,   44,   47,   50,   53,   56,   59,   62,   65,   68,
       71,   74,   77,   80,   83,   86,   89,   92,   94,   96,
       99,  102,  105,  108,  111,  114,  116,  119,  122,  125,
      128,  131,  134,  137,  139,  142,  145,  148,  151,  154,
      157,  160,  163,  166,  169,  172,  175,  178,  181,  184,
      187,  190,  195,  198,  202,  205,  208,  211,  214,  217,

      219,  222,  224,  226,  228,  230,  233,  235,  238,  241,
      243,  246,  249,  252,  255,  258,  262,  265,  267,  269,
      271,  273,  275,  279,  283,  286,  288,  288,  288,  289,
      289,  289,  290,  290,  291,  292,  293,  294,  294,  294,
      294,  294,  297,  298,  298,  299,  300,  301,  302,  303,
      304,  305,  306,  307,  308,  309,  310,  311,  312,  313,
      314,  315,  316,  317,  319,  320,  321,  322,  324,  325,
      326,  327,  328,  329,  329,  329,  329,  330,  331,  332,
      333,  334,  335,  336,  337,  338,  339,  340,  341,  342,
      343,  343,  344,  345,  346,  347,  348,  349,  350,  350,

      351,  352,  353,  354,  355,  356,  357,  358,  359,  360,
      361,  362,  363,  364,  365,  366,  367,  368,  369,  370,
      371,  373,  374,  375,  376,  377,  378,  378,  379,  379,
      379,  379,  379,  379,  380,  380,  381,  382,  383,  384,
      385,  386,  387,  388,  389,  389,  389,  389,  389,  389,
      389,  390,  390,  390,  390,  391,  391,  393,  395,  397,
      398,  399,  399,  400,  401,  402,  403,  404,  405,  405,
      405,  405,  408,  409,  410,  411,  412,  413,  414,  415,
      416,  417,  418,  419,  420,  421,  422,  423,  424,  425,
      427,  428,  429,  430,  431,  432,  433,  434,  435,  435,

      436,  437,  438,  439,  440,  442,  443,  444,  446,  447,
      448,  449,  450,  451,  452,  453,  454,  455,  456,  457,
      458,  459,  460,  461,  462,  463,  464,  465,  466,  467,
      468,  468,  468,  468,  468,  469,  470,  471,  472,  472,
      472,  472,  472,  472,  473,  474,  474,  474,  475,  476,
      477,  478,  479,  480,  481,  482,  483,  484,  485,  486,
      487,  488,  489,  490,  490,  491,  492,  493,  494,  495,
      496,  497,  498,  499,  500,  501,  502,  503,  504,  505,
      506,  507,  508,  509,  510,  511,  512,  513,  514,  515,
      515,  515,  515,  515,  516,  517,  518,  519,  519,  519,

      519,  519,  519,  520,  521,  522,  523,  524,  525,  526,
      527,  528,  529,  530,  531,  532,  532,  533,  534,  535,
      536,  537,  538,  539,  540,  541,  542,  543,  544,  545,
      546,  547,  548,  549,  550,  551,  552,  553,  554,  555,
      555,  555,  555,  555,  556,  557,  558,  559,  559,  559,
      559,  559,  560,  561,  562,  563,  564,  565,  566,  567,
      568,  569,  570,  571,  571,  572,  573,  574,  575,  576,
      577,  578,  579,  580,  581,  582,  583,  584,  585,  586,
      587,  588,  589,  590,  591,  592,  593,  594,  594,  594,
      594,  594,  595,  596,  597,  598,  598,  598,  598,  599,

      600,  601,  602,  603,  604,  605,  606,  607,  608,  609,
      609,  610,  611,  612,  613,  614,  615,  616,  617,  618,
      619,  620,  621,  622,  623,  624,  625,  626,  627,  628,
      629,  630,  631,  631,  631,  631,  631,  632,  633,  634,
      635,  635,  635,  635,  636,  637,  638,  639,  640,  641,
      642,  643,  644,  645,  645,  646,  647,  648,  649,  650,
      651,  652,  653,  654,  655,  656,  657,  658,  659,  660,
      661,  662,  663,  664,  665,  666,  667,  667,  667,  667,
      667,  668,  669,  670,  671,  671,  671,  672,  673,  674,
      675,  676,  677,  678,  679,  680,  681,  681,  682,  683,

      684,  685,  686,  687,  688,  689,  690,  691,  692,  693,
      694,  695,  696,  697,  698,  699,  700,  701,  702,  703,
      703,  703,  703,  703,  704,  705,  706,  707,  707,  707,
      708,  709,  710,  711,  712,  713,  714,  715,  716,  716,
      717,  718,  719,  720,  721,  722,  723,  724,  725,  726,
      727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
      737,  737,  737,  737,  737,  738,  739,  740,  741,  741,
      741,  742,  743,  744,  745,  746,  747,  748,  749,  750,
      750,  751,  752,  753,  754,  755,  756,  757,  758,  759,
      760,  761,  762,  763,  764,  765,  766,  767,  768,  769,

      770,  771,  771,  771,  771,  771,  772,  773,  774,  775,
      775,  775,  776,  777,  778,  779,  781,  782,  783,  783,
      784,  785,  785,  786,  788,  789,  790,  791,  793,  794,
      795,  796,  798,  799,  800,  801,  803,  804,  805,  806,
      808,  809,  810,  811,  813,  814,  815,  815,  815,  815,
      817,  818,  819,  820,  821,  823,  825,  827,  829,  830,
      831,  832,  833,  835,  836,  837,  838,  839,  840,  841,
      842,  843,  844,  845,  846,  847,  848,  849,  850,  850,
      850,  850,  851,  852,  853,  854,  854,  855,  856,  857,
      858,  859,  860,  861,  862,  863,  864,  865,  866,  868,

      869,  869,  869,  870,  871,  872,  873,  874,  875,  876,
      877,  878,  879,  880,  881,  882,  883,  883,  883,  884,
      885,  885,  886,  886,  887,  888,  890,  891,  893,  893
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    1,    6,    1,    7,    8,    1,    1,    9,
       10,    1,    1,    1,    1,   11,    1,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,    1,    1,    1,
        1,    1,   13,   14,   15,   16,   17,   18,   19,   20,
       15,   21,   22,   15,   15,   15,   15,   23,   24,   15,
       15,   25,   26,   27,   28,   15,   15,   15,   15,   15,
        1,    1,    1,    1,   29,    1,   30,   15,   31,   32,

       33,   34,   15,   35,   36,   15,   37,   38,   39,   40,
       41,   42,   15,   43,   44,   45,   46,   15,   47,   15,
       48,   49,   50,    1,   51,   52,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[53] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1
    } ;

static const flex_int16_t yy_base[855] =
    {   0,
        0,   22,    0,   24,   68,    0,  120,    0,  172,    0,
      224,    0,  275,  302,  329,  356,  383,  410,  438,    0,
      489,    0,  535,    0,  566,  597, 2562, 2542, 2541, 2563,
      277,  279,  643,  695,  269,  737,  783,  835,  887,  939,
       38,   40,  260,  268,  272,  264,  295,  266,  288,  296,
      297,  300,  302,  306,  317,  303,  328,  343,  991,  326,
      330,  337,  350, 1021,  385,  395, 2540, 1069, 1121,  349,
      380,  267,  414,  491, 2539, 1173, 1225,  387,  398,  291,
     1277, 1329,  399,  404,  348, 1381, 1433,  407,  409,  353,
     2538,  500,  495,  524,  488, 2537, 2536,  370,  529,  530,

     2535,  490, 2534, 2533,  372,  540,  566, 2532, 1485, 1537,
     1589, 1641,  493,  499,  408, 1692, 1738,  297,  487,  501,
      525,  527, 1770, 1801, 2531,  358, 2530,  528,  560,  550,
     2542, 2528,  572, 1847, 1899, 1951, 2003,  546,  536,  382,
      571,    0, 2527,  565,  585, 2037, 2083, 2135, 2187, 2239,
     2522,    0,  534, 2518, 2516,  569,  292,  571,  329,  261,
      577,  557,  579, 2519,  576,  603,  585, 2518,  588,  600,
      602,  619,  570,  660, 2489,  661, 2520, 2291, 2343,  635,
      637,  616,  604,  643,  642,  644,  646,  647,  645,  687,
      715, 2519, 2514,    0,  653, 2510, 2508,  696,  731, 2515,

     2510,    0,  698, 2506, 2504,  703, 2507,    0,  714, 2503,
     2501,  716, 2504,    0,  720, 2500, 2498,  721, 2505,  732,
      758,  762,  673,  752,  780, 2504,  796, 2503,  710,  785,
      786, 2502,  812, 2501,    0, 2496,    0, 2495,    0,  734,
     2491, 2489,  763, 2394,  754,  655,  658,  805,  735,  740,
     2496,  791,  811,  831, 2495,  664,  836,  840, 2483, 2493,
     2563,  857, 2488,    0,  798, 2487,    0,  800,  800,  854,
      809,  814, 2490,  839, 2485,    0,  848, 2484,    0,  854,
      839,  855,  879, 2477,  867,  880,  860,  884,  886, 2482,
      887,  891,  889,  888,  892,  893,  894, 2563,  956, 2481,

        0,  905,  910,  906,  933,  842,  934, 2480,  937,  919,
      940,  907,  942, 2460,  947,  908,  949, 2459,  950,  961,
      958, 2458,  959,  989,  986, 2457,  987, 2466,  992,  994,
      995, 2465,  999, 1003,  996, 1008, 1006, 2454, 1014, 1015,
     1018, 1017, 1078, 1017, 1024,  975, 1019, 2463, 1027, 1037,
     1035, 2454, 1045, 1068,  938, 1063, 1044, 1049, 1016, 1067,
     1069, 1071, 1072, 1095, 1073, 1090, 1078, 1092, 1115, 1076,
     2452, 1093, 1094, 1113, 2448, 1095, 1122, 1119, 2447, 1126,
     1133, 1129, 2443, 1136, 1137, 1136, 1139,   37,  862, 1142,
     1166, 1146, 1150, 1167, 2442, 1171, 1174, 1157, 1177, 1179,

     1180, 1200, 1177, 1181, 1184, 1187, 1194, 1193,  911, 1217,
     1178, 1214, 1219, 1220, 1223, 1242, 1224, 1226, 1228, 1230,
     1234, 1235, 1245, 1248, 1266, 1274, 1276, 1278, 1279, 1282,
     1286, 1288, 1284, 1292, 1294, 1192, 1293, 1236, 1300, 1254,
     1322, 1301, 1302, 1321, 1326, 1322, 1330,  949, 1313, 1331,
     1358, 1333, 1334, 1339, 1340, 1348, 1352, 2442, 1350, 1370,
     1355, 1374, 1375, 1398, 1376, 1381, 1385, 1353, 1388, 2436,
     1389, 1387, 1397, 2428, 1403, 1390, 1405, 2426, 1407, 1404,
     1428, 2424, 1430, 2424, 1245, 1431, 1439, 2415, 1275, 1436,
     1442, 1443, 1446, 2410, 1447, 1459, 1460, 1461, 1449, 1452,

     1454, 1483, 2403, 1458, 1485, 1486, 1128, 1484, 1487, 1509,
     1492, 1493, 2402, 1494, 1502, 1500, 2398, 1498, 1511, 1507,
     2396, 1509, 1534, 1535, 2392, 1538, 1541, 1544, 1546, 1549,
     1552, 2401, 1553, 1555, 1559, 2398, 2387, 1557, 1583, 1586,
     1564, 1567, 1607, 2383, 2374, 2369, 2357, 1594, 2361, 1562,
     2353, 1517, 1589, 1615, 2349, 1591, 1598, 2351, 1597, 2335,
     1599, 2336, 1605, 2326, 1606, 2317, 1609, 2310, 1636, 2314,
     1634, 2306, 1457, 1614, 1639, 1644, 1651, 1646, 1652, 1653,
     1658, 2304, 1655, 2274, 1643, 1681, 1663, 1666, 1673, 1678,
     1679, 1681, 1682, 1684, 1685, 1665, 1710, 1695, 1280, 1696,

     1692, 1694, 1700, 1701, 1712, 1711, 1709, 1718, 1726, 1723,
     1725, 1728, 1735, 1732, 1740, 1741, 1748, 1718, 1749, 1745,
     1757, 1751, 1758, 1760, 1769, 1767, 1773, 1754, 1794, 1775,
     1787, 1800, 1802, 1770, 1805, 1807, 1792, 1811, 1818, 1839,
     1823, 1842, 1845, 1850, 1853, 1852, 1855, 1859, 1862, 1861,
     1864, 1868, 1871, 1870, 1873, 1891, 1897, 1898, 1902, 1906,
     1909, 1910, 1911, 1915, 1913, 1915, 1917, 1921, 1935, 1960,
     1924, 1925, 1949, 1951, 1785, 1812, 1922, 1971, 1827, 1968,
     1959, 1900, 1958, 1960, 2016, 1969, 1966, 1967, 2018, 1976,
     2001, 1973, 2028, 2012, 2009, 2019, 2057, 2266, 1979, 2010,

     2096, 2247, 2019, 2025, 2098, 2029, 2037, 2047, 2109, 1787,
     2076, 2042, 2054, 2085, 2087,    0, 2090, 2219, 2148, 2214,
     2200, 2128, 2097,    0, 2099, 2191, 2189,    0, 2101, 2182,
     2180,    0, 2106, 2167, 2161,    0, 2129, 2140, 2096, 2107,
     2056, 2136, 2159, 2090, 2137, 2143, 2150, 2151, 2152,    0,
     2154, 2076, 2058, 2196,    0,    0,    0,    0, 2157, 2202,
     2159, 2205,    0, 2186, 2211, 2194, 2198, 2252, 2203, 2206,
     2258, 2208, 2212, 2263, 2246, 2039, 2269, 2240, 2258, 2304,
     2260, 2284, 2271, 2288, 2027, 2312, 2021, 2228, 1992, 2260,
     1952, 2292, 1879, 2293, 1867, 2295, 2305, 2327, 1862, 2146,

     2307, 2306, 1849, 2311, 2356, 2358, 2366, 2367, 2368, 2378,
     2383, 2395, 2400, 2406, 2405, 2417, 2435, 2437, 2443, 2448,
     2453, 1824, 2458, 1762, 2459, 1737, 2471, 1735, 2563, 2490,
     2492, 1684, 2494, 1634, 1591, 1554, 1512, 1487, 2496, 1435,
     1428, 1369, 1102, 1058,  826,  778,  741, 2498,  636,  595,
      523,  494, 2500,  436
    } ;

static const flex_int16_t yy_def[855] =
    {   0,
      829,    1,    1,    1,  829,    5,  829,    7,  829,    9,
      829,   11,  830,  830,  831,  831,  831,  831,  829,   19,
      831,   21,  831,   23,   23,   23,  829,  832,  832,  829,
      832,  833,  834,  835,  832,  832,  836,  837,  838,  838,
       40,   40,   40,   40,   40,   40,   40,   40,   40,   40,
       40,   40,   40,   40,   40,   40,   40,  839,  840,   40,
       40,   40,   40,   40,  832,  832,  832,  841,  841,   69,
       69,   69,  832,  832,  832,  842,  842,   77,   77,   77,
      843,  843,   82,   82,   82,  844,  844,   87,   87,   87,
      845,  845,  829,  845,  845,  845,  845,  845,  832,  832,

      832,  832,  832,  832,  832,  832,  832,  832,  846,  846,
      847,  847,  112,  112,  112,  832,  832,  832,  832,  832,
      832,  832,  832,  832,  832,  832,  832,  832,  832,  833,
      848,  832,  833,  849,  849,  850,  850,  832,  832,  832,
      832,   36,  832,  832,  832,  832,  851,  851,  852,  852,
       40,   40,   40,   40,   40,   40,   40,   40,   40,   40,
       40,   40,   40,   40,   40,   40,   40,   40,   40,   40,
       40,   40,   40,  839,  853,  839,  832,  854,  854,   40,
       40,   40,   40,   40,   40,   40,   40,   40,   40,   40,
      832,  832,   69,   69,   69,   69,   69,   69,  832,  832,

       77,   77,   77,   77,   77,   77,   82,   82,   82,   82,
       82,   82,   87,   87,   87,   87,   87,   87,  845,  845,
      845,  829,  845,  845,  845,  845,  832,  832,  832,  832,
      832,  832,  832,  832,  110,  112,  112,  112,  112,  112,
      112,  112,  112,  832,  832,  832,  832,  832,  832,  832,
      832,  832,  832,  832,  832,  832,  832,  832,  124,  832,
      829,  833,  135,  135,  135,  137,  137,  137,  832,  832,
      832,   36,  832,  832,  148,  148,  148,  150,  150,  150,
       40,   40,   40,   40,   40,   40,   40,   40,   40,   40,
       40,   40,   40,   40,   40,   40,   40,  829,  839,  179,

      179,  179,   40,   40,   40,   40,   40,   40,   40,   40,
       69,   69,   69,   69,   77,   77,   77,   77,   82,   82,
       82,   82,   87,   87,   87,   87,  845,  845,  845,  845,
      832,  832,  832,  832,  112,  112,  112,  112,  832,  832,
      832,  832,  833,  135,  137,  832,  832,  832,  148,  150,
       40,   40,   40,   40,   40,   40,   40,   40,   40,   40,
       40,   40,   40,  839,  179,   40,   40,   40,   40,   69,
       69,   69,   69,   77,   77,   77,   77,   82,   82,   82,
       82,   87,   87,   87,   87,  845,  845,  845,  845,  832,
      832,  832,  832,  112,  112,  112,  112,  832,  832,  832,

      832,  833,  135,  137,  148,  150,   40,   40,   40,   40,
       40,   40,   40,   40,   40,  839,  179,   40,   40,   69,
       69,   69,   69,   77,   77,   77,   77,   82,   82,   82,
       82,   87,   87,   87,   87,  845,  845,  845,  845,  832,
      832,  832,  832,  112,  112,  112,  112,  832,  832,  832,
      833,  135,  137,  148,  150,   40,   40,   40,   40,   40,
       40,   40,   40,  839,  179,   40,   40,   69,   69,   69,
       69,   77,   77,   77,   77,   82,   82,   82,   82,   87,
       87,   87,   87,  845,  845,  845,  845,  832,  832,  832,
      832,  112,  112,  112,  112,  832,  832,  833,  135,  137,

      148,  150,   40,   40,   40,   40,   40,   40,   40,  839,
      179,   40,   69,   69,   69,   69,   77,   77,   77,   77,
       82,   82,   82,   82,   87,   87,   87,   87,  845,  845,
      845,  845,  832,  832,  832,  832,  112,  112,  112,  112,
      832,  832,  833,  135,  137,  148,  150,   40,   40,   40,
       40,   40,   40,  839,  179,   40,   69,   69,   69,   69,
       77,   77,   77,   77,   82,   82,   82,   82,   87,   87,
       87,   87,  845,  845,  845,  845,  832,  832,  832,  832,
      112,  112,  112,  112,  832,  833,  135,  137,  148,  150,
       40,   40,   40,   40,   40,   40,  839,  179,   40,   69,

       69,   69,   69,   77,   77,   77,   77,   82,   82,   82,
       82,   87,   87,   87,   87,  845,  845,  845,  845,  832,
      832,  832,  832,  112,  112,  112,  112,  832,  833,  135,
      137,  148,  150,   40,   40,   40,   40,   40,  839,  179,
       69,   69,   69,   69,   77,   77,   77,   77,   82,   82,
       82,   82,   87,   87,   87,   87,  845,  845,  845,  845,
      832,  832,  832,  832,  112,  112,  112,  112,  832,  833,
      135,  137,  148,  150,   40,   40,   40,   40,   40,  839,
      179,   69,   69,   69,   69,   77,   77,   77,   77,   82,
       82,   82,   82,   87,   87,   87,   87,  845,  845,  845,

      845,  832,  832,  832,  832,  112,  112,  112,  112,  832,
      833,  135,  137,  148,  150,   40,   40,   40,  832,  832,
       40,  839,  179,   69,   69,   69,   69,   77,   77,   77,
       77,   82,   82,   82,   82,   87,   87,   87,   87,  845,
      845,  845,  845,  845,  845,  832,  832,  832,  832,  112,
      112,  112,  112,  833,  135,  137,  148,  150,   40,   40,
       40,  839,  179,   69,   69,   69,   77,   77,   77,   82,
       82,   82,   87,   87,   87,  845,  845,  845,  832,  832,
      832,  112,  112,  112,   40,  832,  832,   40,   69,   69,
       77,   77,   82,   82,   87,   87,  845,  845,  845,  845,

      832,  832,  112,  112,   40,   40,   69,   69,   77,   77,
       82,   82,   87,   87,  845,  845,  832,  832,  112,  112,
      832,  832,  832,  832,  845,  845,  845,  845,    0,  829,
      829,  829,  829,  829,  829,  829,  829,  829,  829,  829,
      829,  829,  829,  829,  829,  829,  829,  829,  829,  829,
      829,  829,  829,  829
    } ;

static const flex_int16_t yy_nxt[2616] =
    {   0,
       28,   29,   30,   31,   28,   32,   33,   34,   28,   28,
       35,   36,   37,   38,   39,   39,   39,   39,   40,   39,
       39,   39,   39,   39,   41,   42,   39,   43,   28,   44,
       45,   46,   47,   48,   39,   49,   39,   50,   51,   52,
       53,   54,   39,   55,   56,   39,   57,   39,   39,   58,
       28,   59,   60,  438,   60,  220,  154,   61,  155,   61,
      151,   62,  151,   62,   63,   64,   63,   64,   28,   65,
       30,   28,   66,   28,   28,   28,   28,   67,   28,   28,
       28,   28,   68,   68,   68,   68,   69,   68,   68,   68,
       68,   68,   70,   71,   68,   72,   28,   68,   68,   68,

       68,   68,   68,   68,   68,   68,   68,   68,   68,   68,
       68,   68,   68,   68,   68,   68,   68,   28,   28,   28,
       28,   73,   30,   28,   74,   28,   28,   28,   28,   75,
       28,   28,   28,   28,   76,   76,   76,   76,   77,   76,
       76,   76,   76,   76,   78,   79,   76,   80,   28,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76,   28,
       28,   28,   28,   29,   30,   28,   28,   28,   28,   28,
       28,   28,   28,   28,   28,   28,   81,   81,   81,   81,
       82,   81,   81,   81,   81,   81,   83,   84,   81,   85,

       28,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   28,   28,   28,   28,   29,   30,   28,   28,   28,
       28,   28,   28,   28,   28,   28,   28,   28,   86,   86,
       86,   86,   87,   86,   86,   86,   86,   86,   88,   89,
       86,   90,   28,   86,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   86,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   28,   28,   28,   92,   93,   94,   94,
      129,  131,  151,  151,  132,  156,  151,  128,  151,  193,
      151,  288,  198,   95,  151,  128,  160,  133,  138,   96,

       97,  158,   98,   92,   93,   94,   94,  157,  139,  140,
      151,  163,  159,  201,  151,  128,  206,  151,  151,  151,
       95,  164,  151,  164,  151,  151,   96,   97,  151,   98,
       99,   30,  161,  100,  162,  169,  165,  166,  101,  151,
      167,  168,  250,  164,  164,  175,  170,  102,  151,  171,
      151,  151,  151,  103,  104,  158,  105,   99,   30,  151,
      100,  176,  173,  164,  172,  101,  180,  196,  287,  181,
      207,  193,  151,  212,  102,  213,  128,  182,  218,  183,
      103,  104,  184,  105,  106,   30,  191,  107,  220,  191,
      128,  185,  108,  177,  192,  226,  191,  232,  197,  191,

      128,  102,  193,  128,  192,  204,  260,  103,  104,  201,
      105,  106,   30,  128,  107,  199,  205,  210,  199,  108,
      201,  207,  211,  200,  271,  216,  207,  217,  102,  213,
      238,  213,  128,  243,  103,  104,  300,  105,   28,  109,
       30,   28,  110,   28,   28,   28,   28,   28,   28,   28,
       28,   28,  111,  111,  111,  111,  112,  111,  111,  111,
      111,  111,  113,  114,  111,  115,   28,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,   28,   28,   28,
      116,   30,  199,  117,  278,  199,  222,  222,  222,  222,

      200,  221,  222,  221,  221,  128,  220,  102,  128,  128,
      223,  241,  229,  103,  104,  238,  105,  242,  220,  128,
      251,  238,  118,  275,  119,  221,  222,  221,  221,  120,
      227,  227,  121,  227,  227,  122,   29,   30,  228,  228,
      251,  233,  220,  128,  233,  128,  128,  128,  128,  234,
      229,  281,  131,  102,  128,  132,  151,  252,  128,  103,
      104,  254,  105,  129,  128,  123,  124,  233,  133,  123,
      233,  123,  253,  123,  131,  234,  270,  132,  128,  151,
      123,  125,  272,  128,  128,  269,  126,  284,  290,  128,
      133,  151,  151,  151,  262,  266,   28,   28,  151,  151,

       28,  151,   28,  128,   28,  297,  292,  151,  285,  125,
      151,   28,  125,  143,  286,  273,  274,  126,  291,  273,
      289,  273,  151,  273,  151,  151,  151,   28,   28,  164,
      273,   28,  293,   28,  164,   28,  263,  294,  151,  295,
      125,  151,   28,  127,  127,  306,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  151,  296,  151,
      305,  135,  175,  175,  151,  151,  151,  151,  151,  151,
      311,  127,  304,  128,  303,  193,  128,  184,  176,  176,
      307,  308,  128,  299,  309,  181,  185,  310,  251,  183,
      327,  220,  127,  127,  127,  127,  127,  251,  127,  127,

      127,  127,  127,  127,  127,  127,  127,  127,  127,  151,
      177,  177,  255,  137,  314,  315,  191,  186,  193,  191,
      201,  318,  187,  127,  192,  201,  188,  331,  128,  189,
      190,  319,  199,  128,  322,  199,  207,  323,  207,  326,
      200,  238,  213,  213,  127,  127,  127,  141,  142,  128,
      220,  335,  143,  128,  223,  128,  238,  144,  128,  221,
      222,  221,  221,  222,  222,  222,  222,  145,  146,  254,
      220,  145,  128,  145,  223,  145,  220,  328,  236,  339,
      143,  338,  145,  127,  127,  238,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  227,  220,  250,

      227,  148,  223,  128,  128,  228,  329,  229,  229,  128,
      332,  127,  333,  233,  128,  344,  233,  345,  128,  348,
      263,  234,  266,  128,  127,  272,  219,  128,  340,  128,
      128,  346,  127,  127,  127,  127,  127,  252,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  128,
      341,  255,  253,  150,  128,  255,  256,  128,  128,  131,
      256,  151,  132,  127,  151,  349,  342,  351,  273,  257,
      275,  350,  128,  352,  343,  133,  278,  151,  439,  255,
      220,  308,  151,  255,  127,  127,  127,  127,  127,  151,
      127,  127,  127,  127,  127,  127,  127,  127,  347,  127,

      127,  151,  151,  355,  164,  152,  151,  353,  151,  151,
      151,  151,  164,  151,  151,  151,  151,  357,  164,  359,
      358,  356,  365,  362,  361,  371,  375,  300,  151,  193,
      201,  363,  151,  151,  458,  360,  127,  127,  127,  127,
      127,  151,  127,  127,  127,  127,  127,  127,  127,  127,
      308,  127,  127,  355,  366,  151,  151,  152,  175,  151,
      151,  153,  193,  369,  193,  308,  367,  128,  370,  201,
      372,  201,  207,  364,  176,  374,  368,  376,  378,  379,
      207,  213,  164,  207,  496,  348,  380,  382,  127,  127,
      127,  127,  127,  128,  127,  127,  127,  127,  127,  127,

      127,  127,  127,  127,  127,  220,  177,  383,  213,  179,
      220,  213,  220,  128,  384,  386,  223,  128,  238,  127,
      388,  128,  389,  390,  394,  229,  395,  392,  238,  348,
      238,  393,  128,  128,  396,  128,  128,  128,  151,  263,
      127,  127,  127,  151,  398,  403,  266,  399,  400,  275,
      164,  186,  404,  171,  401,  405,  187,  151,  213,  278,
      188,  409,  407,  189,  190,  406,  151,  151,  172,  127,
      127,  151,  127,  127,  127,  127,  127,  127,  127,  127,
      131,  127,  127,  132,  410,  151,  164,  194,  412,  151,
      151,  151,  411,  151,  151,  300,  133,  175,  193,  414,

      151,  417,  207,  420,  164,  415,  402,  419,  413,  422,
      423,  426,  151,  176,  151,  193,  193,  201,  127,  127,
      127,  127,  127,  416,  127,  127,  127,  127,  127,  127,
      127,  127,  418,  127,  127,  201,  366,  151,  427,  194,
      424,  207,  430,  195,  201,  177,  428,  308,  207,  431,
      151,  213,  434,  435,  220,  207,  432,  220,  213,  213,
      128,  223,  442,  436,  128,  437,  443,  164,  128,  440,
      127,  127,  127,  127,  127,  128,  127,  127,  127,  127,
      127,  127,  127,  127,  128,  127,  127,  446,  229,  238,
      447,  202,  441,  238,  444,  128,  238,  128,  128,  263,

      151,  448,  131,  266,  452,  132,  275,  449,  453,  278,
      220,  454,  251,  450,  455,  151,  151,  484,  133,  456,
      460,  457,  127,  127,  127,  127,  127,  451,  127,  127,
      127,  127,  127,  127,  127,  127,  151,  127,  127,  151,
      459,  151,  151,  202,  175,  151,  300,  203,  151,  461,
      151,  465,  193,  462,  220,  468,  193,  193,  470,  486,
      176,  530,  469,  220,  164,  463,  466,  193,  471,  464,
      201,  467,  128,  472,  127,  127,  127,  127,  127,  488,
      127,  127,  127,  127,  127,  127,  127,  127,  201,  127,
      127,  534,  177,  128,  473,  208,  201,  474,  201,  475,

      207,  207,  151,  476,  207,  478,  213,  477,  207,  479,
      213,  220,  481,  480,  213,  482,  213,  483,  220,  128,
      128,  485,  308,  487,  490,  491,  127,  127,  127,  127,
      127,  128,  127,  127,  127,  127,  127,  127,  127,  127,
      128,  127,  127,  238,  238,  494,  492,  208,  238,  128,
      489,  209,  238,  495,  493,  263,  266,  251,  499,  500,
      131,  275,  278,  132,  501,  502,  503,  506,  504,  201,
      151,  513,  151,  497,  151,  193,  133,  151,  127,  127,
      127,  127,  127,  498,  127,  127,  127,  127,  127,  127,
      127,  127,  151,  127,  127,  507,  151,  151,  300,  214,

      175,  511,  164,  151,  514,  517,  516,  151,  521,  201,
      193,  193,  207,  518,  508,  509,  176,  308,  512,  201,
      520,  522,  525,  510,  524,  201,  213,  207,  193,  207,
      127,  127,  127,  127,  127,  178,  127,  127,  127,  127,
      127,  127,  127,  127,  526,  127,  127,  528,  177,  220,
      213,  214,  213,  531,  128,  215,  532,  220,  535,  536,
      128,  537,  538,  131,  540,  238,  132,  544,  238,  238,
      545,  263,  546,  616,  266,  220,  275,  128,  128,  543,
      151,  549,  127,  127,  127,  127,  235,  151,  127,  235,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  541,

      542,  547,  550,  237,  551,  278,  151,  151,  151,  151,
      555,  175,  149,  127,  300,  151,  193,  558,  560,  559,
      201,  562,  193,  552,  193,  564,  553,  554,  563,  201,
      556,  207,  566,  201,  127,  127,  127,  127,  235,  151,
      127,  235,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  567,  595,  568,  147,  237,  207,  207,  571,  177,
      213,  570,  572,  213,  220,  127,  213,  220,  223,  575,
      220,  128,  574,  128,  573,  229,  579,  128,  578,  238,
      582,  577,  128,  593,  151,  128,  127,  127,  127,  127,
      127,  136,  127,  127,  127,  127,  127,  127,  127,  127,

      583,  127,  127,  251,  584,  238,  585,  239,  238,  131,
      591,  151,  132,  151,  600,  604,  151,  175,  602,  193,
      193,  201,  608,  599,  596,  133,  606,  201,  207,  262,
      610,  207,  220,  176,  134,  586,  617,  299,  127,  127,
      127,  127,  127,  597,  127,  127,  127,  127,  127,  127,
      127,  127,  612,  127,  127,  614,  213,  220,  213,  239,
      618,  128,  220,  240,  128,  177,  223,  620,  621,  128,
      128,  128,  619,  622,  624,  229,  626,  238,  628,  630,
      238,  623,  631,  131,  127,  263,  132,  151,  266,  632,
      127,  127,  127,  244,  633,  275,  244,  629,  635,  133,

      278,  151,  634,  151,  151,  637,  151,  151,  636,  642,
      128,  640,  175,  638,  193,  164,  193,  300,  193,  641,
      643,  644,  193,  201,  645,  245,  639,  246,  176,  646,
      648,  201,  247,  201,  201,  248,  220,  647,  249,  244,
      207,  649,  244,  650,  659,  207,  652,  207,  207,  651,
      213,  653,  654,  220,  213,  220,  128,  213,  655,  220,
      177,  656,  213,  128,  657,  658,  220,  220,  661,  128,
      660,  245,  128,  246,  662,  128,  128,  663,  247,  664,
      128,  248,  238,  665,  249,  255,  666,  675,  128,  238,
      256,  238,  151,  667,  668,  238,  131,  263,  671,  132,

      257,  258,  669,  716,  257,  128,  257,  151,  257,  266,
      672,  678,  133,  255,  151,  257,  255,  670,  251,  128,
      175,  256,  275,  673,  278,  674,  676,  151,  677,  151,
      259,  257,  258,  151,  151,  257,  176,  257,  717,  257,
      682,  680,  128,  679,  255,  193,  257,  127,  127,  151,
      127,  127,  127,  127,  127,  127,  127,  127,  164,  127,
      127,  300,  681,  683,  193,  264,  684,  193,  177,  685,
      686,  819,  193,  687,  201,  201,  688,  201,  689,  690,
      220,  201,  691,  207,  207,  692,  207,  693,  694,  813,
      207,  695,  213,  213,  696,  213,  127,  127,  127,  127,

      127,  811,  127,  127,  127,  127,  127,  127,  127,  127,
      697,  127,  127,  213,  698,  220,  220,  264,  724,  699,
      220,  265,  193,  700,  220,  701,  702,  128,  128,  128,
      706,  703,  704,  128,  705,  238,  707,  238,  708,  238,
      709,  712,  713,  238,  151,  718,  263,  266,  127,  127,
      127,  127,  127,  128,  127,  127,  127,  127,  127,  127,
      127,  127,  131,  127,  127,  132,  714,  710,  715,  267,
      175,  275,  719,  278,  809,  719,  723,  711,  133,  720,
      193,  300,  193,  726,  725,  722,  176,  728,  201,  201,
      730,  201,  729,  151,  732,  207,  734,  220,  207,  721,

      127,  127,  127,  127,  127,  741,  127,  127,  127,  127,
      127,  127,  127,  127,  807,  127,  127,  719,  177,  719,
      719,  267,  719,  207,  720,  268,  720,  733,  220,  719,
      736,  213,  719,  742,  213,  737,  720,  128,  193,  128,
      201,  213,  738,  128,  727,  747,  731,  750,  748,  805,
      207,  238,  127,  127,  127,  128,  735,  220,  719,  238,
      755,  719,  797,  751,  263,  720,  145,  273,  274,  238,
      752,  273,  756,  273,  220,  273,  266,  776,  131,  213,
      784,  132,  273,  127,  127,  739,  127,  127,  127,  127,
      127,  127,  127,  127,  754,  127,  127,  743,  783,  719,

      743,  276,  719,  757,  744,  758,  720,  275,  220,  278,
      719,  759,  151,  719,  220,  763,  128,  720,  775,  300,
      764,  193,  767,  201,  745,  220,  749,  770,  207,  223,
      175,  238,  127,  127,  127,  127,  127,  753,  127,  127,
      127,  127,  127,  127,  127,  127,  762,  127,  127,  719,
      773,  213,  719,  276,  220,  220,  720,  277,  777,  778,
      743,  128,  774,  743,  220,  229,  128,  744,  128,  128,
      128,  779,  816,  780,  781,  782,  238,  220,  177,  151,
      785,  151,  788,  772,  127,  127,  127,  127,  127,  771,
      127,  127,  127,  127,  127,  127,  127,  127,  131,  127,

      127,  132,  769,  786,  768,  279,  786,  175,  193,  789,
      787,  766,  786,  765,  133,  786,  193,  790,  262,  787,
      201,  791,  761,  176,  151,  201,  792,  299,  207,  793,
      207,  794,  128,  193,  213,  795,  127,  127,  127,  127,
      127,  760,  127,  127,  127,  127,  127,  127,  127,  127,
      151,  127,  127,  786,  806,  177,  786,  279,  220,  786,
      787,  280,  786,  800,  786,  746,  787,  786,  213,  796,
      798,  787,  786,  798,  201,  786,  128,  799,  128,  787,
      207,  801,  193,  802,  740,  213,  808,  220,  127,  127,
      127,  127,  127,  238,  127,  127,  127,  127,  127,  127,

      127,  127,  627,  127,  127,  786,  238,  803,  786,  301,
      238,  804,  787,  786,  201,  207,  786,  213,  810,  812,
      787,  814,  128,  220,  128,  128,  625,  815,  798,  817,
      128,  798,  818,  238,  615,  799,  613,  820,  611,  609,
      127,  127,  127,  127,  127,  220,  127,  127,  127,  127,
      127,  127,  127,  127,  607,  127,  127,  821,  605,  823,
      821,  301,  823,  603,  822,  302,  824,  821,  823,  821,
      821,  823,  821,  601,  822,  824,  822,  598,  151,  823,
      151,  594,  823,  592,  821,  590,  824,  821,  193,  193,
      201,  822,  127,  127,  127,  244,  823,  589,  244,  823,

      201,  821,  588,  824,  821,  207,  825,  823,  822,  825,
      823,  587,  128,  826,  824,  581,  580,  207,  827,  576,
      569,  827,  213,  220,  565,  828,  561,  245,  213,  246,
      557,  548,  539,  533,  247,  220,  821,  248,  823,  821,
      249,  823,  529,  822,  821,  824,  527,  821,  523,  823,
      519,  822,  823,  128,  821,  128,  824,  821,  515,  823,
      825,  822,  823,  825,  505,  238,  824,  826,  445,  433,
      238,  128,  827,  429,  425,  827,  128,  220,  421,  828,
      408,  128,  397,  391,  387,  385,  381,  377,  373,  220,
       91,   91,   28,   28,  130,  130,  174,  174,  131,  131,

      175,  175,  151,  300,  151,  354,  278,  275,  128,  266,
      263,  128,  127,  128,  128,  337,  336,  238,  238,  128,
      334,  128,  330,  220,  325,  324,  213,  321,  320,  207,
      317,  316,  201,  128,  313,  312,  193,  128,  128,  298,
      151,  151,  283,  282,  151,  128,  128,  261,  128,  128,
      128,  231,  230,  128,  225,  224,  220,  128,  128,  128,
      128,  829,   27,  829,  829,  829,  829,  829,  829,  829,
      829,  829,  829,  829,  829,  829,  829,  829,  829,  829,
      829,  829,  829,  829,  829,  829,  829,  829,  829,  829,
      829,  829,  829,  829,  829,  829,  829,  829,  829,  829,

      829,  829,  829,  829,  829,  829,  829,  829,  829,  829,
      829,  829,  829,  829,  829
    } ;

static const flex_int16_t yy_chk[2616] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    2,  388,    4,  388,   41,    2,   42,    4,
       41,    2,   42,    4,    2,    2,    4,    4,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,

        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,

        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   13,   13,   13,   13,
       31,   32,   43,  160,   32,   43,   46,   35,   48,   72,
       44,  160,   72,   13,   45,   31,   46,   32,   35,   13,

       13,   45,   13,   14,   14,   14,   14,   44,   35,   35,
       49,   48,   45,   80,  157,  118,   80,   47,   50,   51,
       14,   49,   52,  157,   53,   56,   14,   14,   54,   14,
       15,   15,   47,   15,   47,   54,   50,   51,   15,   55,
       52,   53,  118,   56,   53,   58,   54,   15,   60,   55,
       57,  159,   61,   15,   15,   60,   15,   16,   16,   62,
       16,   58,   57,   61,   55,   16,   60,   70,  159,   61,
       85,   70,   63,   85,   16,   90,  126,   62,   90,   62,
       16,   16,   63,   16,   17,   17,   65,   17,   98,   65,
      105,   63,   17,   58,   65,   98,   66,  105,   71,   66,

      140,   17,   71,   65,   66,   78,  126,   17,   17,   78,
       17,   18,   18,   66,   18,   73,   79,   83,   73,   18,
       79,   83,   84,   73,  140,   88,   84,   89,   18,   88,
      115,   89,   73,  115,   18,   18,  854,   18,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       21,   21,   74,   21,  852,   74,   93,   93,   93,   93,

       74,   92,   92,   92,   92,  119,   95,   21,  102,   74,
       95,  113,  102,   21,   21,  113,   21,  114,   92,  120,
      119,  114,   21,  851,   21,   94,   94,   94,   94,   21,
       99,  100,   21,   99,  100,   21,   23,   23,   99,  100,
      120,  106,   94,  121,  106,  122,  128,   99,  100,  106,
      128,  153,  130,   23,  139,  130,  153,  121,  106,   23,
       23,  122,   23,  129,  138,   23,   23,  107,  130,   23,
      107,   23,  121,   23,  133,  107,  139,  133,  129,  162,
       23,   25,  141,  144,  107,  138,   25,  156,  162,  141,
      133,  156,  173,  158,  133,  850,   25,   25,  165,  161,

       25,  163,   25,  145,   25,  173,  165,  167,  158,   25,
      169,   25,   26,  144,  158,  145,  145,   26,  163,  145,
      161,  145,  170,  145,  171,  166,  183,   26,   26,  167,
      145,   26,  169,   26,  166,   26,  849,  170,  182,  171,
       26,  172,   26,   33,   33,  183,   33,   33,   33,   33,
       33,   33,   33,   33,   33,   33,   33,  180,  172,  181,
      182,   33,  174,  176,  185,  184,  186,  189,  187,  188,
      195,   33,  181,  246,  180,  195,  247,  189,  174,  176,
      184,  185,  256,  176,  186,  187,  189,  188,  246,  188,
      223,  223,   33,   33,   33,   34,   34,  247,   34,   34,

       34,   34,   34,   34,   34,   34,   34,   34,   34,  190,
      174,  176,  256,   34,  198,  203,  191,  190,  198,  191,
      203,  206,  190,   34,  191,  206,  190,  229,  229,  190,
      190,  209,  199,  191,  212,  199,  209,  215,  212,  218,
      199,  847,  215,  218,   34,   34,   34,   36,   36,  199,
      220,  240,   36,  249,  220,   36,  240,   36,  250,  221,
      221,  221,  221,  222,  222,  222,  222,   36,   36,  249,
      224,   36,  245,   36,  224,   36,  221,  224,  846,  250,
       36,  243,   36,   37,   37,  243,   37,   37,   37,   37,
       37,   37,   37,   37,   37,   37,   37,  227,  225,  245,

      227,   37,  225,  230,  231,  227,  225,  230,  231,  252,
      230,   37,  231,  233,  227,  265,  233,  268,  269,  271,
      265,  233,  268,  248,  272,  272,  845,  271,  252,  253,
      233,  269,   37,   37,   37,   38,   38,  248,   38,   38,
       38,   38,   38,   38,   38,   38,   38,   38,   38,  254,
      253,  257,  248,   38,  257,  258,  257,  274,  258,  262,
      258,  281,  262,   38,  306,  277,  254,  281,  274,  258,
      277,  280,  270,  282,  262,  262,  280,  282,  389,  257,
      389,  306,  287,  258,   38,   38,   38,   39,   39,  285,
       39,   39,   39,   39,   39,   39,   39,   39,  270,   39,

       39,  283,  286,  287,  285,   39,  288,  283,  289,  291,
      294,  293,  286,  292,  295,  296,  297,  291,  289,  293,
      292,  288,  302,  296,  295,  312,  316,  302,  304,  312,
      316,  297,  303,  409,  409,  294,   39,   39,   39,   40,
       40,  310,   40,   40,   40,   40,   40,   40,   40,   40,
      304,   40,   40,  303,  303,  305,  307,   40,  299,  309,
      355,   40,  311,  310,  313,  305,  307,  448,  311,  315,
      313,  317,  319,  299,  299,  315,  309,  317,  319,  320,
      321,  323,  355,  320,  448,  346,  321,  323,   40,   40,
       40,   59,   59,  346,   59,   59,   59,   59,   59,   59,

       59,   59,   59,   59,   59,  327,  299,  324,  325,   59,
      329,  324,  330,  331,  325,  327,  330,  333,  335,   59,
      329,  334,  330,  331,  335,  334,  336,  333,  337,  347,
      336,  334,  339,  340,  337,  342,  341,  347,  359,  344,
       59,   59,   59,   64,  339,  344,  345,  340,  341,  349,
      359,   64,  345,   64,  342,  349,   64,  351,  844,  350,
       64,  353,  351,   64,   64,  350,  357,  353,   64,   68,
       68,  358,   68,   68,   68,   68,   68,   68,   68,   68,
      343,   68,   68,  343,  354,  356,  358,   68,  357,  360,
      354,  361,  356,  362,  363,  365,  343,  364,  370,  361,

      367,  365,  843,  370,  363,  362,  343,  367,  360,  372,
      373,  376,  366,  364,  368,  372,  373,  376,   68,   68,
       68,   69,   69,  364,   69,   69,   69,   69,   69,   69,
       69,   69,  366,   69,   69,  374,  368,  369,  377,   69,
      374,  378,  380,   69,  377,  364,  378,  369,  380,  381,
      507,  382,  384,  385,  386,  381,  382,  387,  384,  385,
      390,  387,  392,  386,  392,  387,  393,  507,  393,  390,
       69,   69,   69,   76,   76,  398,   76,   76,   76,   76,
       76,   76,   76,   76,  391,   76,   76,  396,  391,  394,
      397,   76,  391,  396,  394,  399,  397,  400,  401,  403,

      411,  398,  402,  404,  403,  402,  405,  399,  404,  406,
      436,  405,  401,  400,  406,  408,  407,  436,  402,  407,
      411,  408,   76,   76,   76,   77,   77,  402,   77,   77,
       77,   77,   77,   77,   77,   77,  412,   77,   77,  410,
      410,  413,  414,   77,  416,  415,  417,   77,  418,  412,
      419,  417,  420,  413,  438,  420,  421,  422,  422,  438,
      416,  485,  421,  485,  414,  415,  418,  423,  423,  416,
      424,  419,  440,  424,   77,   77,   77,   81,   81,  440,
       81,   81,   81,   81,   81,   81,   81,   81,  425,   81,
       81,  489,  416,  489,  425,   81,  426,  426,  427,  427,

      428,  429,  599,  428,  430,  430,  433,  429,  431,  431,
      432,  437,  433,  432,  434,  434,  435,  435,  439,  442,
      443,  437,  599,  439,  442,  443,   81,   81,   81,   82,
       82,  449,   82,   82,   82,   82,   82,   82,   82,   82,
      441,   82,   82,  444,  446,  446,  444,   82,  445,  450,
      441,   82,  447,  447,  445,  452,  453,  449,  452,  453,
      451,  454,  455,  451,  454,  455,  456,  459,  457,  842,
      456,  468,  459,  450,  457,  468,  451,  461,   82,   82,
       82,   86,   86,  451,   86,   86,   86,   86,   86,   86,
       86,   86,  460,   86,   86,  461,  462,  463,  465,   86,

      464,  465,  460,  466,  469,  472,  471,  467,  476,  472,
      469,  471,  476,  473,  462,  463,  464,  467,  466,  473,
      475,  477,  480,  464,  479,  475,  480,  477,  841,  479,
       86,   86,   86,   87,   87,  840,   87,   87,   87,   87,
       87,   87,   87,   87,  481,   87,   87,  483,  464,  486,
      481,   87,  483,  486,  490,   87,  487,  487,  490,  491,
      491,  492,  493,  498,  495,  492,  498,  499,  493,  495,
      500,  499,  501,  573,  500,  573,  501,  496,  497,  498,
      504,  504,   87,   87,   87,  109,  109,  838,  109,  109,
      109,  109,  109,  109,  109,  109,  109,  109,  109,  496,

      497,  502,  505,  109,  506,  502,  508,  505,  506,  509,
      511,  510,  837,  109,  511,  512,  514,  514,  516,  515,
      518,  518,  516,  508,  515,  520,  509,  510,  519,  520,
      512,  522,  522,  519,  109,  109,  109,  110,  110,  552,
      110,  110,  110,  110,  110,  110,  110,  110,  110,  110,
      110,  523,  552,  524,  836,  110,  523,  524,  527,  510,
      526,  526,  528,  527,  529,  110,  528,  530,  529,  531,
      531,  533,  530,  534,  529,  533,  535,  535,  534,  538,
      538,  533,  541,  550,  550,  542,  110,  110,  110,  111,
      111,  835,  111,  111,  111,  111,  111,  111,  111,  111,

      539,  111,  111,  541,  540,  539,  542,  111,  540,  543,
      548,  553,  543,  556,  557,  561,  548,  554,  559,  559,
      557,  561,  565,  556,  553,  543,  563,  563,  565,  543,
      567,  567,  574,  554,  834,  543,  574,  554,  111,  111,
      111,  112,  112,  554,  112,  112,  112,  112,  112,  112,
      112,  112,  569,  112,  112,  571,  571,  575,  569,  112,
      575,  585,  576,  112,  578,  554,  576,  577,  578,  577,
      579,  580,  576,  579,  581,  580,  583,  583,  585,  587,
      581,  580,  588,  586,  832,  587,  586,  596,  588,  589,
      112,  112,  112,  116,  590,  589,  116,  586,  592,  586,

      590,  591,  591,  592,  593,  594,  594,  595,  593,  601,
      116,  598,  597,  596,  601,  595,  602,  598,  600,  600,
      602,  603,  603,  604,  604,  116,  597,  116,  597,  605,
      607,  607,  116,  606,  605,  116,  618,  606,  116,  117,
      608,  608,  117,  609,  618,  610,  611,  611,  609,  610,
      612,  612,  613,  828,  614,  826,  117,  613,  614,  616,
      597,  615,  615,  620,  616,  617,  617,  619,  620,  622,
      619,  117,  628,  117,  621,  621,  623,  622,  117,  623,
      824,  117,  624,  624,  117,  123,  625,  634,  123,  626,
      123,  625,  634,  626,  627,  627,  629,  630,  630,  629,

      123,  123,  628,  675,  123,  710,  123,  675,  123,  631,
      631,  637,  629,  123,  637,  123,  124,  629,  710,  124,
      639,  124,  632,  632,  633,  633,  635,  635,  636,  636,
      124,  124,  124,  638,  676,  124,  639,  124,  676,  124,
      641,  639,  822,  638,  124,  641,  124,  134,  134,  679,
      134,  134,  134,  134,  134,  134,  134,  134,  679,  134,
      134,  640,  640,  642,  642,  134,  643,  643,  639,  644,
      645,  803,  644,  646,  646,  645,  647,  647,  648,  649,
      799,  648,  650,  650,  649,  651,  651,  652,  653,  795,
      652,  654,  654,  653,  655,  655,  134,  134,  134,  135,

      135,  793,  135,  135,  135,  135,  135,  135,  135,  135,
      656,  135,  135,  656,  657,  657,  658,  135,  682,  658,
      659,  135,  682,  659,  660,  660,  661,  661,  662,  663,
      665,  662,  663,  664,  664,  665,  666,  666,  667,  667,
      668,  671,  672,  668,  677,  677,  671,  672,  135,  135,
      135,  136,  136,  669,  136,  136,  136,  136,  136,  136,
      136,  136,  670,  136,  136,  670,  673,  669,  674,  136,
      680,  673,  678,  674,  791,  678,  681,  670,  670,  678,
      683,  681,  684,  684,  683,  680,  680,  686,  687,  688,
      688,  686,  687,  678,  690,  692,  692,  699,  690,  678,

      136,  136,  136,  137,  137,  699,  137,  137,  137,  137,
      137,  137,  137,  137,  789,  137,  137,  685,  680,  689,
      685,  137,  689,  691,  685,  137,  689,  691,  700,  693,
      694,  695,  693,  700,  694,  695,  693,  703,  685,  787,
      689,  696,  696,  704,  685,  703,  689,  706,  704,  785,
      693,  706,  137,  137,  137,  146,  693,  776,  697,  707,
      712,  697,  776,  707,  712,  697,  146,  146,  146,  708,
      708,  146,  713,  146,  741,  146,  713,  741,  711,  697,
      753,  711,  146,  147,  147,  697,  147,  147,  147,  147,
      147,  147,  147,  147,  711,  147,  147,  701,  752,  705,

      701,  147,  705,  714,  701,  715,  705,  714,  744,  715,
      709,  717,  717,  709,  701,  723,  705,  709,  739,  723,
      725,  725,  729,  729,  701,  740,  705,  733,  733,  740,
      722,  709,  147,  147,  147,  148,  148,  709,  148,  148,
      148,  148,  148,  148,  148,  148,  722,  148,  148,  719,
      737,  737,  719,  148,  742,  745,  719,  148,  742,  745,
      743,  746,  738,  743,  800,  746,  719,  743,  747,  748,
      749,  747,  800,  748,  749,  751,  751,  743,  722,  759,
      759,  761,  761,  735,  148,  148,  148,  149,  149,  734,
      149,  149,  149,  149,  149,  149,  149,  149,  754,  149,

      149,  754,  731,  760,  730,  149,  760,  762,  764,  764,
      760,  727,  765,  726,  754,  765,  766,  766,  754,  765,
      767,  767,  721,  762,  760,  769,  769,  762,  770,  770,
      772,  772,  720,  765,  773,  773,  149,  149,  149,  150,
      150,  718,  150,  150,  150,  150,  150,  150,  150,  150,
      788,  150,  150,  768,  788,  762,  768,  150,  778,  771,
      768,  150,  771,  778,  774,  702,  771,  774,  775,  775,
      777,  774,  783,  777,  768,  783,  779,  777,  781,  783,
      771,  779,  790,  781,  698,  774,  790,  777,  150,  150,
      150,  178,  178,  783,  178,  178,  178,  178,  178,  178,

      178,  178,  584,  178,  178,  780,  782,  782,  780,  178,
      784,  784,  780,  786,  792,  794,  786,  796,  792,  794,
      786,  796,  780,  797,  802,  801,  582,  797,  798,  801,
      786,  798,  802,  804,  572,  798,  570,  804,  568,  566,
      178,  178,  178,  179,  179,  798,  179,  179,  179,  179,
      179,  179,  179,  179,  564,  179,  179,  805,  562,  806,
      805,  179,  806,  560,  805,  179,  806,  807,  808,  809,
      807,  808,  809,  558,  807,  808,  809,  555,  805,  810,
      806,  551,  810,  549,  811,  547,  810,  811,  807,  808,
      809,  811,  179,  179,  179,  244,  812,  546,  244,  812,

      810,  813,  545,  812,  813,  811,  815,  814,  813,  815,
      814,  544,  244,  815,  814,  537,  536,  812,  816,  532,
      525,  816,  813,  815,  521,  816,  517,  244,  814,  244,
      513,  503,  494,  488,  244,  816,  817,  244,  818,  817,
      244,  818,  484,  817,  819,  818,  482,  819,  478,  820,
      474,  819,  820,  817,  821,  818,  820,  821,  470,  823,
      825,  821,  823,  825,  458,  819,  823,  825,  395,  383,
      820,  821,  827,  379,  375,  827,  823,  825,  371,  827,
      352,  348,  338,  332,  328,  326,  322,  318,  314,  827,
      830,  830,  831,  831,  833,  833,  839,  839,  848,  848,

      853,  853,  308,  300,  290,  284,  278,  275,  273,  266,
      263,  260,  259,  255,  251,  242,  241,  238,  236,  234,
      232,  228,  226,  219,  217,  216,  213,  211,  210,  207,
      205,  204,  201,  200,  197,  196,  193,  192,  177,  175,
      168,  164,  155,  154,  151,  143,  132,  131,  127,  125,
      108,  104,  103,  101,   97,   96,   91,   75,   67,   29,
       28,   27,  829,  829,  829,  829,  829,  829,  829,  829,
      829,  829,  829,  829,  829,  829,  829,  829,  829,  829,
      829,  829,  829,  829,  829,  829,  829,  829,  829,  829,
      829,  829,  829,  829,  829,  829,  829,  829,  829,  829,

      829,  829,  829,  829,  829,  829,  829,  829,  829,  829,
      829,  829,  829,  829,  829
    } ;

#define YY_TRAILING_MASK 0x2000
#define YY_TRAILING_HEAD_MASK 0x4000
#define REJECT \
{ \
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */ \
yy_cp = yyg->yy_full_match; /* restore poss. backed-over text */ \
yyg->yy_lp = yyg->yy_full_lp; /* restore orig. accepting pos. */ \
yyg->yy_state_ptr = yyg->yy_full_state; /* restore orig. state */ \
yy_current_state = *yyg->yy_state_ptr; /* restore curr. state */ \
++yyg->yy_lp; \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "nksp.l"
/*
 * Copyright (c) 2015-2025 Christian Schoenebeck
 *
 * http://www.linuxsampler.org
 *
 * This file is part of LinuxSampler and released under the same terms.
 * See README file for details.
 */
/* Token scanner used for generating syntax highlighting for NKSP instrument
   script language code (this is not used by the sampler itself, but rather
   provided for external script editor applications). */
#line 15 "nksp.l"

#include "NkspScanner.h"
// reentrant scanner data context
#define YY_EXTRA_TYPE NkspScanner*
// custom (f)lex input for reading from std::istream object
#define YY_INPUT(buf,result,max_size)   \
{                                       \
    char c = yyextra->is->get();        \
    if (yyextra->is->eof())             \
        result = YY_NULL;               \
    else {                              \
        buf[0] = c;                     \
        result = 1;                     \
    }                                   \
}
// handle position (line, column) for each recognized token
#define YY_USER_ACTION               \
    yyextra->line   = yylineno - 1;  \
    yyextra->column = yycolumn;      \
    yyextra->offset += (int) yyleng; \
    yyextra->length =  (int) yyleng; \
    yycolumn += yyleng;

using namespace LinuxSampler;

static int countNewLineChars(const char* txt) {
    int n = 0;
    for (int i = 0; txt[i]; ++i)
        if (txt[i] == '\n') ++n;
    return n;
}

// shut up warning that 'register' keyword is deprecated as of C++11
#if defined(__cplusplus) && __cplusplus >= 201103L
# define register
#endif

// Since this parser is solely used by script code editors, thus not used in a
// real-time context, always throw an exception instead of exiting on fatal
// lexer errors (so the debugger may pause with the appropriate back trace)
#include <stdexcept>
#define YY_FATAL_ERROR(msg) throw std::runtime_error(msg)

#line 1653 "nksp.cpp"
/* generate a reentrant safe scanner */
/* avoid symbol collision with ones of other scanners */
/* yywrap() would be called at EOF, we don't need it */
/* enable functions yy_push_state(), yy_pop_state(), yy_top_state() */
/* inclusive scanner conditions */

/* exclusive scanner conditions */

#line 1662 "nksp.cpp"

#define INITIAL 0
#define PREPROC_BODY_USE 1
#define PREPROC_SET_COND 2
#define PREPROC_RESET_COND 3
#define PREPROC_IF 4
#define PREPROC_IF_NOT 5
#define PREPROC_BODY_EAT 6
#define PREPROC_PRE_BODY_USE 7
#define PREPROC_PRE_BODY_EAT 8
#define PREPROC_EVENT_NAME 9
#define PREPROC_END_NAME 10
#define METRIC 11
#define UNIT 12

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    yy_state_type *yy_state_buf;
    yy_state_type *yy_state_ptr;
    char *yy_full_match;
    int yy_lp;

    /* These are only needed for trailing context rules,
     * but there's no conditional variable for that yet. */
    int yy_looking_for_trail_begin;
    int yy_full_lp;
    int *yy_full_state;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  , yyscan_t yyscanner);
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

    static void yy_push_state ( int _new_state , yyscan_t yyscanner);
    
    static void yy_pop_state ( yyscan_t yyscanner );
    
    static int yy_top_state ( yyscan_t yyscanner );
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (yyscan_t yyscanner);

#define YY_DECL int yylex (yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! yyg->yy_state_buf )
            yyg->yy_state_buf = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  , yyscanner);
            if ( ! yyg->yy_state_buf )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 80 "nksp.l"


#line 1963 "nksp.cpp"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
		yy_current_state += YY_AT_BOL();

		yyg->yy_state_ptr = yyg->yy_state_buf;
		*yyg->yy_state_ptr++ = yy_current_state;

yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 830 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			*yyg->yy_state_ptr++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 2563 );

yy_find_action:
		yy_current_state = *--yyg->yy_state_ptr;
		yyg->yy_lp = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( yyg->yy_lp && yyg->yy_lp < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[yyg->yy_lp];
				if ( yy_act & YY_TRAILING_HEAD_MASK ||
				     yyg->yy_looking_for_trail_begin )
					{
					if ( yy_act == yyg->yy_looking_for_trail_begin )
						{
						yyg->yy_looking_for_trail_begin = 0;
						yy_act &= ~YY_TRAILING_HEAD_MASK;
						break;
						}
					}
				else if ( yy_act & YY_TRAILING_MASK )
					{
					yyg->yy_looking_for_trail_begin = yy_act & ~YY_TRAILING_MASK;
					yyg->yy_looking_for_trail_begin |= YY_TRAILING_HEAD_MASK;
					}
				else
					{
					yyg->yy_full_match = yy_cp;
					yyg->yy_full_state = yyg->yy_state_ptr;
					yyg->yy_full_lp = yyg->yy_lp;
					break;
					}
				++yyg->yy_lp;
				goto find_rule;
				}
			--yy_cp;
			yy_current_state = *--yyg->yy_state_ptr;
			yyg->yy_lp = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 82 "nksp.l"
{
    yyextra->token = StringLiteralToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 87 "nksp.l"
{
    yyextra->token = NumberLiteralToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 92 "nksp.l"
{
    yy_push_state(METRIC, yyscanner);
    yyextra->token = NumberLiteralToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 98 "nksp.l"
{
    yy_push_state(UNIT, yyscanner);
    yyextra->token = NumberLiteralToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 104 "nksp.l"
{
    yyextra->token = MetricPrefixToken(yytext);
    yy_pop_state(yyscanner);
    return yyextra->token.baseType;
}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 110 "nksp.l"
{
    yyextra->token = MetricPrefixToken(yytext);
    yy_pop_state(yyscanner);
    yy_push_state(UNIT, yyscanner);
    return yyextra->token.baseType;
}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 117 "nksp.l"
{
    yyextra->token = StdUnitToken(yytext);
    yy_pop_state(yyscanner);
    return yyextra->token.baseType;
}
	YY_BREAK
/* Preprocessor statement:  SET_CONDITION(name) */
case 8:
YY_RULE_SETUP
#line 126 "nksp.l"
{
    //printf("SET_CONDITION\n");
    yy_push_state(PREPROC_SET_COND, yyscanner);
    yyextra->token = PreprocessorToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 132 "nksp.l"
{
    //printf("preproc set condition '%s'\n", yytext);
    yyextra->token = PreprocessorToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 137 "nksp.l"
{
    //printf("End of PREPROC_SET_COND\n");
    yy_pop_state(yyscanner);
    yyextra->token = PreprocessorToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
/* Preprocessor statement:  RESET_CONDITION(name) */
case 11:
YY_RULE_SETUP
#line 147 "nksp.l"
{
    //printf("RESET_CONDITION\n");
    yy_push_state(PREPROC_RESET_COND, yyscanner);
    yyextra->token = PreprocessorToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 153 "nksp.l"
{
    //printf("preproc reset condition '%s'\n", yytext);
    yyextra->token = PreprocessorToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 158 "nksp.l"
{
    //printf("End of RESET_CONDITION\n");
    yy_pop_state(yyscanner);
    yyextra->token = PreprocessorToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
/* Preprocessor conditional statements:

    USE_CODE_IF(name)
      ...
    END_USE_CODE

    and:

    USE_CODE_IF_NOT(name)
      ...
    END_USE_CODE    
 */
case 14:
YY_RULE_SETUP
#line 179 "nksp.l"
{
    //printf("USE_CODE_IF\n");
    yy_push_state(PREPROC_IF, yyscanner);
    yyextra->token = PreprocessorToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 185 "nksp.l"
{
    //printf("USE_CODE_IF_NOT\n");
    yy_push_state(PREPROC_IF_NOT, yyscanner);
    yyextra->token = PreprocessorToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 191 "nksp.l"
{
    //printf("preproc use code if '%s'\n", yytext);
    yy_pop_state(yyscanner);
    yy_push_state(PREPROC_PRE_BODY_USE, yyscanner);
    //yy_push_state(PREPROC_PRE_BODY_EAT, yyscanner);
    yyextra->token = PreprocessorToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 199 "nksp.l"
{
    //printf("preproc use code if not '%s'\n", yytext);
    yy_pop_state(yyscanner);
    yy_push_state(PREPROC_PRE_BODY_USE, yyscanner);
    //yy_push_state(PREPROC_PRE_BODY_EAT, yyscanner);
    yyextra->token = PreprocessorToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 207 "nksp.l"
{
    yy_pop_state(yyscanner);
    yy_push_state(PREPROC_BODY_USE, yyscanner);
    yyextra->token = PreprocessorToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 213 "nksp.l"
{
    //printf("PREPROCESSOR EAT : \n");
    yy_pop_state(yyscanner);
    yy_push_state(PREPROC_BODY_EAT, yyscanner);
    yyextra->token = PreprocessorToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 220 "nksp.l"
{
    //printf("-->END_USE_CODE\n");
    yy_pop_state(yyscanner);
    yyextra->token = PreprocessorToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 226 "nksp.l"
/* eat up code block filtered out by preprocessor */
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 227 "nksp.l"
/* eat up code block filtered out by preprocessor */
	YY_BREAK
/* Event Handler Names (only if they occur alone in a document!) */
case 23:
YY_RULE_SETUP
#line 232 "nksp.l"
{
    yyextra->token = EventHandlerNameToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
/* Language keywords */
case 24:
YY_RULE_SETUP
#line 240 "nksp.l"
{
    yy_push_state(PREPROC_EVENT_NAME, yyscanner);
    yyextra->token = KeywordToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 246 "nksp.l"
{
    yy_pop_state(yyscanner);
    yyextra->token = EventHandlerNameToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 252 "nksp.l"
{
    yy_push_state(PREPROC_END_NAME, yyscanner);
    yyextra->token = KeywordToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 258 "nksp.l"
{
    yy_pop_state(yyscanner);
    yyextra->token = KeywordToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 264 "nksp.l"
{
    yyextra->token = KeywordToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 269 "nksp.l"
{
    yyextra->token = KeywordToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
/* Variables */
case 30:
YY_RULE_SETUP
#line 277 "nksp.l"
{
    yyextra->token = IntegerVariableToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 282 "nksp.l"
{
    yyextra->token = RealVariableToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 287 "nksp.l"
{
    yyextra->token = StringVariableToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 292 "nksp.l"
{
    yyextra->token = IntegerArrayVariableToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 297 "nksp.l"
{
    yyextra->token = RealArrayVariableToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 302 "nksp.l"
{
    yyextra->token = IdentifierToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
/* other */
case 36:
/* rule 36 can match eol */
YY_RULE_SETUP
#line 310 "nksp.l"
{
    yyextra->token = NewLineToken();
    ++yylineno;
    yycolumn = 0;
    return yyextra->token.baseType;
}
	YY_BREAK
case 37:
/* rule 37 can match eol */
YY_RULE_SETUP
#line 317 "nksp.l"
{
    yyextra->token = CommentToken(yytext);
    yylineno += countNewLineChars(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 323 "nksp.l"
{
    yyextra->token = OtherToken("    ");
    return yyextra->token.baseType;
}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 328 "nksp.l"
/* eat up \r */
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(PREPROC_BODY_USE):
case YY_STATE_EOF(PREPROC_SET_COND):
case YY_STATE_EOF(PREPROC_RESET_COND):
case YY_STATE_EOF(PREPROC_IF):
case YY_STATE_EOF(PREPROC_IF_NOT):
case YY_STATE_EOF(PREPROC_BODY_EAT):
case YY_STATE_EOF(PREPROC_PRE_BODY_USE):
case YY_STATE_EOF(PREPROC_PRE_BODY_EAT):
case YY_STATE_EOF(PREPROC_EVENT_NAME):
case YY_STATE_EOF(PREPROC_END_NAME):
case YY_STATE_EOF(METRIC):
case YY_STATE_EOF(UNIT):
#line 330 "nksp.l"
{
    yyextra->token = EofToken();
    yyterminate();
}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 335 "nksp.l"
{
    yyextra->token = OtherToken(yytext);
    return yyextra->token.baseType;
}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 341 "nksp.l"
ECHO;
	YY_BREAK
#line 2443 "nksp.cpp"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;
	yy_current_state += YY_AT_BOL();

	yyg->yy_state_ptr = yyg->yy_state_buf;
	*yyg->yy_state_ptr++ = yy_current_state;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 830 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		*yyg->yy_state_ptr++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */

	YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 830 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 829);
	if ( ! yy_is_jam )
		*yyg->yy_state_ptr++ = yy_current_state;

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp , yyscan_t yyscanner)
{
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yy_cp = yyg->yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yyg->yy_hold_char;

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = yyg->yy_n_chars + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			yyg->yy_n_chars = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	yyg->yytext_ptr = yy_bp;
	yyg->yy_hold_char = *yy_cp;
	yyg->yy_c_buf_p = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

    static void yy_push_state (int  _new_state , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( yyg->yy_start_stack_ptr >= yyg->yy_start_stack_depth )
		{
		yy_size_t new_size;

		yyg->yy_start_stack_depth += YY_START_STACK_INCR;
		new_size = (yy_size_t) yyg->yy_start_stack_depth * sizeof( int );

		if ( ! yyg->yy_start_stack )
			yyg->yy_start_stack = (int *) yyalloc( new_size , yyscanner );

		else
			yyg->yy_start_stack = (int *) yyrealloc(
					(void *) yyg->yy_start_stack, new_size , yyscanner );

		if ( ! yyg->yy_start_stack )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	yyg->yy_start_stack[yyg->yy_start_stack_ptr++] = YY_START;

	BEGIN(_new_state);
}

    static void yy_pop_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( --yyg->yy_start_stack_ptr < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN(yyg->yy_start_stack[yyg->yy_start_stack_ptr]);
}

    static int yy_top_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	return yyg->yy_start_stack[yyg->yy_start_stack_ptr - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

    yyg->yy_state_buf = 0;
    yyg->yy_state_ptr = 0;
    yyg->yy_full_match = 0;
    yyg->yy_lp = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    yyfree ( yyg->yy_state_buf , yyscanner);
    yyg->yy_state_buf  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 341 "nksp.l"


namespace LinuxSampler {

int NkspScanner::processScanner() {
    return Nksp_lex(scanner);
}

void NkspScanner::createScanner(std::istream* is) {
    if (scanner) destroyScanner();
    this->is = is;
    Nksp_lex_init(&scanner);
    Nksp_set_extra(this, scanner);
}

void NkspScanner::destroyScanner() {
    if (!scanner) return;
    Nksp_lex_destroy(scanner);
    scanner = NULL;
}

} // namespace LinuxSampler

